
## cli命令

### 1. 安装

```bash
pip install cpan123
```
### 2. 使用
```bash
cpan123 [command] [options]
```
### 3. 命令列表

- 暂时只提供下面两个命令

```bash

cpan123 upload [options]  # 上传文件到123秒传
cpan123 download [options]  # 下载文件

```


帮助信息

```bash
cpan123 --help  # 查看所有命令的帮助信息
cpan123 upload --help  # 查看上传命令的帮助信息
cpan123 download --help  # 查看下载命令的帮助信息
```